from typing import Any

__credits__: str

def parse_mime_type(mime_type: Any): ...
def parse_media_range(range: Any): ...
def fitness_and_quality_parsed(mime_type: Any, parsed_ranges: Any): ...
def quality_parsed(mime_type: Any, parsed_ranges: Any): ...
def quality(mime_type: Any, ranges: Any): ...
def best_match(supported: Any, header: Any): ...
