from typing import Any, Optional

def init(
    argv: Any,
    name: Any,
    version: Any,
    doc: Any,
    filename: Any,
    scope: Optional[Any] = ...,
    parents: Any = ...,
    discovery_filename: Optional[Any] = ...,
): ...
