from typing import Any, Optional

HAS_GOOGLE_AUTH: bool
HAS_OAUTH2CLIENT: bool

def credentials_from_file(
    filename: Any, scopes: Optional[Any] = ..., quota_project_id: Optional[Any] = ...
): ...
def default_credentials(
    scopes: Optional[Any] = ..., quota_project_id: Optional[Any] = ...
): ...
def with_scopes(credentials: Any, scopes: Any): ...
def authorized_http(credentials: Any): ...
def refresh_credentials(credentials: Any): ...
def apply_credentials(credentials: Any, headers: Any): ...
def is_valid(credentials: Any): ...
def get_credentials_from_http(http: Any): ...
